@@ -171,13 +171,10 @@ expr_range <- function(srcref) {
 }
 
 get_range_text <- function(content, line1, col1, line2, col2) {
-    text <- content[line1:line2]
-    text[[1]] <- substr(text[[1]], col1, nchar(text[[1]]))
-    if (line2 > line1) {
-        nlines <- length(text)
-        text[[nlines]] <- substr(text[[nlines]], col2, nchar(text[[nlines]]))
-    }
-    text
+    lines <- content[line1:line2]
+    lines[length(lines)] <- substr(lines[length(lines)], 1L, col2)
+    lines[1] <- substr(lines[1], col1, nchar(lines[1]))
+    lines
 }
 
 parse_expr <- function(content, expr, env, level = 0L, srcref = attr(expr, "srcref")) {
